package cz.moneta.test.dsl.ib.insurance.travel;

import cz.moneta.test.dsl.ib.IbPageFlow;
import cz.moneta.test.dsl.ib.components.MainMenu;
import cz.moneta.test.harness.support.web.Click;
import cz.moneta.test.harness.support.web.Wait;

import static cz.moneta.test.dsl.ib.insurance.travel.LongTermTravelInsuranceCreatePage.CONTINUE_BUTTON;

@Wait(CONTINUE_BUTTON)
public interface LongTermTravelInsuranceCreatePage extends IbPageFlow<LongTermTravelInsuranceCreatePage>, MainMenu {

    String ACCOUNT_SELECT = "//select[@name='accountNumber']";
    String REGION_EUROPE_SELECT = "//input[@id='regionEurope']";
    String REGION_WORLD_SELECT = "//input[@id='regionWorld']";
    String VARIANT_SINGLE_SELECT = "//input[@id='variantSingle']";
    String VARIANT_FAMILY_SELECT = "//input[@id='variantFamily']";
    String LICENCE_AGREEMENT_CHECKBOX = "//input[@name='licenceAgreement1']";
    String INSURANCE_AGREEMENT_CHECKBOX = "//input[@name='licenceAgreement2']";
    String CONTINUE_BUTTON = "//a[@id='btnContinue']";

    @Click(ACCOUNT_SELECT)
    LongTermTravelInsuranceCreatePage clickAccountSelect();

    @Click(REGION_EUROPE_SELECT)
    LongTermTravelInsuranceCreatePage clickRegionEuropeSelect();

    @Click(REGION_WORLD_SELECT)
    LongTermTravelInsuranceCreatePage clickRegionWorldSelect();

    @Click(VARIANT_SINGLE_SELECT)
    LongTermTravelInsuranceCreatePage clickVariantSingleSelect();

    @Click(VARIANT_FAMILY_SELECT)
    LongTermTravelInsuranceCreatePage clickVariantFamilySelect();

    @Click(LICENCE_AGREEMENT_CHECKBOX)
    LongTermTravelInsuranceCreatePage clickLicenceAgreement();

    @Click(INSURANCE_AGREEMENT_CHECKBOX)
    LongTermTravelInsuranceCreatePage clickInsuranceAgreement();

    @Click(CONTINUE_BUTTON)
    LongTermTravelInsuranceAuthorizePage clickContinueButton();
}